@@ -1,7 +1,7 @@
 //
 // ImLogWindow.cs
 //
-// Lukas Lipka <lukas@pmad.net>
+// Lukas Lipka <lukaslipka@gmail.com>
 // Raphael  Slinckx <rslinckx@gmail.com>
 //
 // Copyright (C) 2005 Novell, Inc.
@@ -92,14 +92,16 @@ namespace ImLogViewer {
 
 			// Find the buddy
 			ImBuddy buddy = null;
+			ImBuddyListReader reader = null;
 
-			if (client == ImClient.Gaim)
-				buddy = new GaimBuddyListReader ().Search (speaker);
-			else if (client == ImClient.Kopete)
-				buddy = new KopeteBuddyListReader ().Search (speaker);
-			else if (client == ImClient.Konversation) {
+			if (client == ImClient.Pidgin) {
+				reader = new PidginBuddyListReader ();
+				buddy = reader.Search (speaker);
+			} else if (client == ImClient.Kopete) {
+				reader = new KopeteBuddyListReader ();
+				buddy = reader.Search (speaker);
+			} else if (client == ImClient.Konversation) {
 				int pos = speaker.IndexOf ('_');
-				string server, channel;
 
 				// speaker of the form irc.gimp.net_#mono-dev
 				if (pos == -1)
@@ -185,8 +187,8 @@ namespace ImLogViewer {
 				ImLog log = null;
 				StreamReader reader = new StreamReader (file);
 				
-				if (client == ImClient.Gaim)
-					log = new GaimLog (new FileInfo (file), reader);
+				if (client == ImClient.Pidgin)
+					log = new PidginLog (new FileInfo (file), reader);
 				else if (client == ImClient.Kopete)
 					log = new KopeteLog (new FileInfo (file), reader);
 				else if (client == ImClient.Konversation)
@@ -245,10 +247,11 @@ namespace ImLogViewer {
 			}
 
 			if (preview == null)
-				return ((ImLog.Utterance) log.Utterances [0]).Text;
+				preview = ((ImLog.Utterance) log.Utterances [0]).Text;
 
 			if (preview.Length > 50)
-				return preview.Substring (0, 50) + "...";
+				preview = preview.Substring (0, 50) + "...";
+
 			return preview;
 		}
 
