@@ -30,6 +30,7 @@ using System.Globalization;
 using System.IO;
 using System.Text;
 using System.Xml;
+using System.Text.RegularExpressions;
 
 using Mono.Unix;
 
@@ -702,7 +703,9 @@ namespace Beagle.Util {
 			
 			System.Text.StringBuilder sb = 
 				new System.Text.StringBuilder ( (dollar_pos == 0 ? "" : path.Substring (0, dollar_pos)));
-			
+
+			bool env_var_found = false;
+
 			while (dollar_pos != -1 && dollar_pos + 1 < path.Length) {
 				// FIXME: kconfigbase.cpp contains an additional case, $(expression)/.kde/...
 				// Ignoring such complicated expressions for now. Volunteers ;) ?
@@ -724,11 +727,15 @@ namespace Beagle.Util {
 							end_pos ++;
 						var_name = path.Substring (dollar_pos + 1, end_pos - dollar_pos - 1);
 					}
+
 					string value_env = null;
 					if (var_name != String.Empty)
 						value_env = Environment.GetEnvironmentVariable (var_name);
 					if (value_env != null) {
 						sb.Append (value_env);
+						env_var_found = true;
+					} else {
+						env_var_found = false;
 					}
 					// else, no environment variable with that name exists. ignore
 				}else // else, ignore the first '$', second one will be expanded
@@ -743,6 +750,9 @@ namespace Beagle.Util {
 				}
 			}
 
+			if (! env_var_found)
+				return null;
+
 			return sb.ToString ();
 		}
 
@@ -796,44 +806,57 @@ namespace Beagle.Util {
 		
 		public static string ConvertSpecialEntities (string line)
 		{
-			line.Replace ("&lt;", "<");
-			line.Replace ("&gt;", ">");
-			line.Replace ("&quot;", "\"");
-			line.Replace ("&amp;", "&");
-			line.Replace ("&nbsp", " ");
+			line = line.Replace ("&lt;", "<");
+			line = line.Replace ("&gt;", ">");
+			line = line.Replace ("&quot;", "\"");
+			line = line.Replace ("&amp;", "&");
+			line = line.Replace ("&nbsp", " ");
 
 			return line;
   		}
-	}
 
-	public class HtmlRemovingReader : TextReader {
-
-		private TextReader reader;
-		private StringBuilder sb;
-	    
-		public HtmlRemovingReader (TextReader reader)
+		public static Regex GetPatternRegex (IEnumerable patterns)
 		{
-			this.reader = reader;
-			this.sb = new StringBuilder ();
-		}
-
-		public override string ReadLine ()
-		{
-			string line = reader.ReadLine ();
-
-			if (line == null)
+			if (patterns == null)
 				return null;
 
-			sb.Length = 0;
-			line = StringFu.StripTags (line, sb);
-			line = StringFu.ConvertSpecialEntities (line);
+			StringBuilder sb = new StringBuilder ();
+			bool first = true;
+			Regex tmp_regex = null;
+			foreach (string pattern in patterns) {
+				try {
+					string regex_pattern;
+					if (pattern.Length >= 2 && pattern [0] == '/' && pattern.EndsWith ("/")) {
+						regex_pattern = pattern.Substring (1, pattern. Length - 2);
+					} else {
+						// Make *.foo to .*\.foo
+						regex_pattern = pattern.Replace (".", @"\.");
+						regex_pattern = regex_pattern.Replace ("*", ".*");
+					}
+					tmp_regex = new Regex (regex_pattern);
+					sb.Append (String.Format (@"{0}^(?:{1})$", first ? String.Empty : "|", regex_pattern));
+				} catch (System.ArgumentException) {
+					Log.Warn ("Ignoring invalid regex: [{0}]", pattern);
+				}
+				first = false;
+			}
 
-			return line;
+			// If no patterns are there, prevent generating a regex that will match everything
+			if (sb.Length == 0)
+				return null;
+
+			//Log.Debug ("regex: [{0}]", sb.ToString());
+			return new Regex (sb.ToString (), RegexOptions.Compiled);
 		}
 
-		public override void Close ()
-		{
-			reader.Close ();
+		public class OrdinalComparer : IComparer {
+
+			public static OrdinalComparer Instance = new OrdinalComparer ();
+
+			public int Compare (object a, object b)
+			{
+				return String.CompareOrdinal ((string) a, (string) b);
+			}
 		}
 	}
 }
