@@ -39,6 +39,7 @@ using Log = Beagle.Util.Log;
 using Stopwatch = Beagle.Util.Stopwatch;
 
 namespace Beagle.Daemon {
+
 	class BeagleDaemon {
 
 		public static Thread MainLoopThread = null;
@@ -50,13 +51,24 @@ namespace Beagle.Daemon {
 		private static bool arg_disable_scheduler = false;
 		private static bool arg_indexing_test_mode = false;
 		private static bool arg_heap_shot = false;
+		private static bool arg_heap_shot_snapshots = true;
+
+		private static bool disable_textcache = false;
+		public static bool DisableTextCache {
+			get { return disable_textcache; }
+			set { disable_textcache = value; }
+		}
+
+#if ENABLE_AVAHI
+		private static Beagle.Daemon.Network.Zeroconf zeroconf = null;
+#endif
 
 		public static bool StartServer ()
 		{
 			Logger.Log.Debug ("Starting messaging server");
 
 			try {
-				server = new Server ("socket");
+				server = new Server ("socket", false, Conf.Networking.GetOption (Conf.Names.ServiceEnabled, false));
 				server.Start ();
 			} catch (InvalidOperationException) {
 				return false;
@@ -116,7 +128,7 @@ namespace Beagle.Daemon {
 
 				int vm_rss = SystemInformation.VmRss;
 
-				if (arg_heap_shot)
+				if (arg_heap_shot && arg_heap_shot_snapshots)
 					MaybeSendSigprof (vm_rss, GC.GetTotalMemory (false));
 
 				if (vm_rss > 300 * 1024) {
@@ -130,31 +142,30 @@ namespace Beagle.Daemon {
 
 		private static void PrintUsage ()
 		{
-			string usage =
-				"beagled: The daemon to the Beagle search system.\n" +
-				"Web page: http://beagle-project.org\n" +
-				"Copyright (C) 2004-2006 Novell, Inc.\n\n";
+			VersionFu.PrintHeader ();
 
-			usage +=
+			string usage =
 				"Usage: beagled [OPTIONS]\n\n" +
 				"Options:\n" +
 				"  --foreground, --fg\tRun the daemon in the foreground.\n" +
 				"  --background, --bg\tRun the daemon in the background.\n" +
-				"  --replace\t\tReplace a running daemon with a new instance.\n" +
-				"  --debug\t\tWrite out debugging information.\n" +
-				"  --debug-memory\tWrite out debugging information about memory use.\n" +
-				"  --indexing-test-mode\tRun in foreground, and exit when fully indexed.\n" +
-				"  --indexing-delay\tTime to wait before indexing.  (Default 60 seconds)\n" +
 				"  --backend\t\tConfigure which backends to use.  Specifically:\n" +
 				"    --backend <name>\tOnly start backend 'name'\n" +
 				"    --backend +<name>\tAdditionally start backend 'name'\n" +
 				"    --backend -<name>\tDisable backend 'name'\n" +
-				"  --allow-backend\t(DEPRECATED) Start only the specific backend.\n" +
-				"  --deny-backend\t(DEPRECATED) Deny a specific backend.\n" +
+				"  --replace\t\tReplace a running daemon with a new instance.\n" +
 				"  --list-backends\tList all the available backends.\n" +
 				"  --add-static-backend\tAdd a static backend by path.\n" + 
+				"  --help\t\tPrint this usage message.\n" +
+				"  --version\t\tPrint version information.\n" +
+				"\n" +
+				"Advanced options:\n" +
+				"  --debug\t\tWrite out debugging information.\n" +
+				"  --debug-memory\tWrite out debugging information about memory use.\n" +
+				"  --indexing-test-mode\tRun in foreground, and exit when fully indexed.\n" +
+				"  --indexing-delay <t>\tWait 't' seconds before indexing.  (Default 60 seconds)\n" +
 				"  --disable-scheduler\tDisable the use of the scheduler.\n" +
-				"  --help\t\tPrint this usage message.\n";
+				"  --disable-text-cache\tDisable the use of the text cache used to provide snippets.\n";
 
 			Console.WriteLine (usage);
 		}
@@ -184,9 +195,13 @@ namespace Beagle.Daemon {
 			// Set up out-of-process indexing
 			LuceneQueryable.IndexerHook = new LuceneQueryable.IndexerCreator (RemoteIndexer.NewRemoteIndexer);
 
+			Config config = Conf.Get (Conf.Names.DaemonConfig);
+
 			// Initialize synchronization to keep the indexes local if PathFinder.StorageDir
 			// is on a non-block device, or if BEAGLE_SYNCHRONIZE_LOCALLY is set
-			if ((! SystemInformation.IsPathOnBlockDevice (PathFinder.StorageDir) && Conf.Daemon.IndexSynchronization) ||
+
+			if ((! SystemInformation.IsPathOnBlockDevice (PathFinder.StorageDir) &&
+			     config.GetOption (Conf.Names.IndexSynchronization, true)) ||
 			    Environment.GetEnvironmentVariable ("BEAGLE_SYNCHRONIZE_LOCALLY") != null)
 				IndexSynchronization.Initialize ();
 
@@ -194,7 +209,7 @@ namespace Beagle.Daemon {
 			Logger.Log.Debug ("Starting QueryDriver");
 			QueryDriver.Start ();
 
-			bool initially_on_battery = SystemInformation.UsingBattery && ! Conf.Indexing.IndexOnBattery;
+			bool initially_on_battery = SystemInformation.UsingBattery && ! config.GetOption (Conf.Names.IndexOnBattery, false);
 
 			// Start the Global Scheduler thread
 			if (! arg_disable_scheduler) {
@@ -210,7 +225,8 @@ namespace Beagle.Daemon {
 			// will become some sort of D-BUS signal, probably from
 			// something like gnome-power-manager.
 			prev_on_battery = initially_on_battery;
-			GLib.Timeout.Add (5000, CheckBatteryStatus);
+			// Use 1 sec more than acpi poll interval
+			GLib.Timeout.Add (((int) SystemInformation.acpi_poll_delay + 1) * 1000, CheckBatteryStatus);
 
 			// Start our Inotify threads
 			Inotify.Start ();
@@ -219,6 +235,10 @@ namespace Beagle.Daemon {
 			// warning if not.  The actual advice calls will fail silently.
 			FileAdvise.TestAdvise ();
 
+#if ENABLE_AVAHI
+               	        zeroconf = new Beagle.Daemon.Network.Zeroconf ();
+#endif
+
 			Conf.WatchForUpdates ();
 
 			stopwatch.Stop ();
@@ -233,6 +253,7 @@ namespace Beagle.Daemon {
 				Scheduler.Global.EmptyQueueEvent += OnEmptySchedulerQueue;
 				Scheduler.Global.Add (null); // pulse the scheduler
 			}
+
 			return false;
 		}
 
@@ -316,6 +337,11 @@ namespace Beagle.Daemon {
 					arg_debug_memory = true;
 					break;
 
+				case "--no-snapshots":
+				case "--no-snapshot":
+					arg_heap_shot_snapshots = false;
+					break;
+
 				case "--heap-buddy":
 				case "--debug-memory":
 					arg_debug = true;
@@ -352,22 +378,6 @@ namespace Beagle.Daemon {
 					++i; // we used next_arg
 					break;
 				
-				case "--allow-backend":
-					// --allow-backend is deprecated, use --backends 'name' instead
-					// it will disable reading the list of enabled/disabled backends
-					// from conf and start the backend given
-					if (next_arg != null)
-						QueryDriver.OnlyAllow (next_arg);
-					++i; // we used next_arg
-					break;
-					
-				case "--deny-backend":
-					// deprecated: use --backends -'name' instead
-					if (next_arg != null)
-						QueryDriver.Deny (next_arg);
-					++i; // we used next_arg
-					break;
-
 			       case "--add-static-backend": 
 					if (next_arg != null)
 						QueryDriver.AddStaticQueryable (next_arg);
@@ -395,6 +405,15 @@ namespace Beagle.Daemon {
 					// FIXME: This option is deprecated and will be removed in a future release.
 					break;
 
+				case "--disable-text-cache":
+					disable_textcache = true;
+					break;
+					
+				case "--version":
+					VersionFu.PrintVersion ();
+					Environment.Exit (0);
+					break;
+
 				default:
 					Console.WriteLine ("Unknown argument '{0}'", arg);
 					Environment.Exit (1);
@@ -403,10 +422,14 @@ namespace Beagle.Daemon {
 				}
 			}
 
+			if (Environment.GetEnvironmentVariable ("SABAYON_SESSION_RUNNING") == "yes") {
+				Console.WriteLine ("Beagle is running underneath Sabayon, exiting.");
+				Environment.Exit (0);
+			}
+
 			if (arg_indexing_test_mode) {
 				LuceneQueryable.OptimizeRightAway = true;
 			}
-				
 
 			// Bail out if we are trying to run as root
 			if (Environment.UserName == "root" && Environment.GetEnvironmentVariable ("SUDO_USER") != null) {
@@ -417,7 +440,7 @@ namespace Beagle.Daemon {
 				Environment.Exit (-1);
 			}
 
-			if (Environment.UserName == "root" && ! Conf.Daemon.AllowRoot) {
+			if (Environment.UserName == "root" && ! Conf.Daemon.GetOption (Conf.Names.AllowRoot, false)) {
 				Console.WriteLine ("You can not run beagle as root.  Beagle is designed to run from your own");
 				Console.WriteLine ("user account.  If you want to create multiuser or system-wide indexes, use");
 				Console.WriteLine ("the beagle-build-index tool.");
@@ -445,7 +468,6 @@ namespace Beagle.Daemon {
 
 			Log.Always ("Starting Beagle Daemon (version {0})", ExternalStringsHack.Version);
 			Log.Always ("Running on {0}", SystemInformation.MonoRuntimeVersion);
-			Log.Always ("Using sqlite version {0}", ExternalStringsHack.SqliteVersion);
 			Log.Always ("Command Line: {0}",
 					   Environment.CommandLine != null ? Environment.CommandLine : "(null)");
 
@@ -454,6 +476,17 @@ namespace Beagle.Daemon {
 						 "Performance will suffer as a result.");
 			}
 
+			if (disable_textcache) {
+				Log.Warn ("Running with text-cache disabled!");
+				Log.Warn ("*** Snippets will not be returned for documents indexed in this session.");
+			}
+
+			// Check if global configuration files are installed
+			if (! Conf.CheckGlobalConfig ()) {
+				Console.WriteLine ("Global configuration files not found in {0}", Conf.GlobalDir);
+				Environment.Exit (-1);
+			}
+
 			// Start our memory-logging thread
 			if (arg_debug_memory)
 				ExceptionHandlingThread.Start (new ThreadStart (LogMemoryUsage));
@@ -470,6 +503,9 @@ namespace Beagle.Daemon {
 				Logger.Log.Debug ("Unable to establish a connection to the X server");
 			XSetIOErrorHandler (BeagleXIOErrorHandler);
 
+			// Lower our CPU priority
+			SystemPriorities.Renice (7);
+
 			QueryDriver.Init ();
 			Server.Init ();
 
@@ -485,7 +521,7 @@ namespace Beagle.Daemon {
 			GLib.Idle.Add (new GLib.IdleHandler (StartupProcess));
 
 			// Start our event loop.
-			Logger.Log.Debug ("Starting main loop");
+			//Logger.Log.Debug ("Starting main loop");
 			main_loop.Run ();
 
 			// We're out of the main loop now, join all the
@@ -509,12 +545,14 @@ namespace Beagle.Daemon {
 
 		private static bool CheckBatteryStatus ()
 		{
-			if (prev_on_battery && (! SystemInformation.UsingBattery || Conf.Indexing.IndexOnBattery)) {
+			bool index_on_battery = Conf.Daemon.GetOption (Conf.Names.IndexOnBattery, false);
+
+			if (prev_on_battery && (! SystemInformation.UsingBattery || index_on_battery)) {
 				if (! SystemInformation.UsingBattery)
-					Log.Info ("Deletected a switch from battery to AC power.  Restarting scheduler.");
+					Log.Info ("Detected a switch from battery to AC power.  Restarting scheduler.");
 				Scheduler.Global.Start ();
 				prev_on_battery = false;
-			} else if (! prev_on_battery && SystemInformation.UsingBattery && ! Conf.Indexing.IndexOnBattery) {
+			} else if (! prev_on_battery && SystemInformation.UsingBattery && ! index_on_battery) {
 				Log.Info ("Detected a switch from AC power to battery.  Stopping scheduler.");
 				Scheduler.Global.Stop ();
 				prev_on_battery = true;
@@ -606,6 +644,9 @@ namespace Beagle.Daemon {
 
 		private static void OnShutdown ()
 		{
+#if ENABLE_AVAHI
+			zeroconf.Dispose ();
+#endif			
 			// Stop our Inotify threads
 			Inotify.Stop ();
 
