@@ -27,6 +27,7 @@
 
 using System;
 using System.Collections;
+using System.Collections.Generic;
 using System.IO;
 using System.Runtime.Serialization.Formatters.Binary;
 using System.Threading;
@@ -48,9 +49,12 @@ namespace Beagle.Daemon.EvolutionMailQueryable {
 		private static ArrayList excludes = new ArrayList ();
 
 		static EvolutionMailIndexableGenerator () {
-			foreach (ExcludeItem exclude in Conf.Indexing.Excludes)
-				if (exclude.Type == ExcludeType.MailFolder)
-					excludes.Add (exclude);
+			List<string[]> values = Conf.Daemon.GetListOptionValues (Conf.Names.ExcludeMailfolder);
+			if (values == null)
+				return;
+
+			foreach (string[] item in values)
+				excludes.Add (item [0].ToLower ());
 		}
 
 		protected EvolutionMailQueryable queryable;
@@ -101,8 +105,8 @@ namespace Beagle.Daemon.EvolutionMailQueryable {
 		protected bool IgnoreFolder (string path)
 		{
 			// FIXME: Use System.IO.Path
-			foreach (ExcludeItem exclude in excludes) {
-				if (exclude.IsMatch (path))
+			foreach (string exclude in excludes) {
+				if (path.StartsWith (exclude))
 					return true;
 			}
 			return false;
@@ -322,7 +326,7 @@ namespace Beagle.Daemon.EvolutionMailQueryable {
 			indexable.Timestamp = message.Date.ToUniversalTime ();
 			indexable.HitType = "MailMessage";
 			indexable.MimeType = "message/rfc822";
-			indexable.CacheContent = false;
+			indexable.CacheContent = true;
 
 			indexable.AddProperty (Property.NewUnsearched ("fixme:client", "evolution"));
 			indexable.AddProperty (Property.NewUnsearched ("fixme:account", "Local"));
