@@ -53,6 +53,7 @@ using Beagle.Util;
 namespace Beagle.Daemon.IndexingServiceQueryable {
 
 	[QueryableFlavor (Name="IndexingService", Domain=QueryDomain.Local, RequireInotify=false)]
+	[PropertyKeywordMapping (Keyword="host", PropertyName="fixme:host", IsKeyword=false, Description="The host of this entitiy.")]
 	public class IndexingServiceQueryable : LuceneQueryable {
 
 		public IndexingServiceQueryable () : base ("IndexingServiceIndex")
@@ -79,14 +80,10 @@ namespace Beagle.Daemon.IndexingServiceQueryable {
 
 			Logger.Log.Info ("Setting up an initial crawl of the IndexingService directory");
 
-			State = QueryableState.Crawling;
-
 			IndexableGenerator generator = new IndexableGenerator (GetIndexables (index_path));
 			Scheduler.Task task = NewAddTask (generator);
 			task.Tag = "IndexingService initial crawl";
 			ThisScheduler.Add (task);
-
-			State = QueryableState.Idle;
 		}
 
 		private IEnumerable GetIndexables (string path)
@@ -133,6 +130,7 @@ namespace Beagle.Daemon.IndexingServiceQueryable {
 			indexable.Timestamp = data_file.LastWriteTimeUtc;
 			indexable.ContentUri = UriFu.PathToFileUri (data_file.FullName);
 			indexable.DeleteContent = true;
+			indexable.AddProperty( Property.New("fixme:host",uri.Host));
 
 			// Second line is the hit type
 			line = reader.ReadLine ();
@@ -244,37 +242,91 @@ namespace Beagle.Daemon.IndexingServiceQueryable {
 			ThisScheduler.Add (task);
 		}
 
-		protected override void PostAddHook (Indexable indexable, IndexerAddedReceipt receipt)
+		protected override Uri PostAddHook (Indexable indexable, IndexerAddedReceipt receipt)
 		{
-			FileInfo meta_file = (FileInfo) indexable.LocalState ["MetaFile"];
+			FileInfo meta_file = indexable.LocalState ["MetaFile"] as FileInfo;
+			if (meta_file == null)
+				return indexable.Uri;
+
 			meta_file.Delete ();
 
 			lock (pending_files)
 				pending_files.Remove (indexable.ContentUri.LocalPath);
+
+			return indexable.Uri;
 		}
 
 		private class IndexableGenerator : IIndexableGenerator {
-			private IEnumerator to_add_enumerator;
+			private IEnumerator to_add_enumerator = null, to_remove_uris_enumerator = null;
 			private int count = -1, done_count = 0;
+			// FIXME: Unused. Use this to store the submitter queryable in the localstate
+			// of the indexables and receive PostHooks() from LuceneQueryable
+			private LuceneQueryable submitter_queryable = null;
 
 			public IndexableGenerator (IEnumerable to_add)
 			{
 				this.to_add_enumerator = to_add.GetEnumerator ();
 			}
 
-			public IndexableGenerator (ICollection to_add) : this ((IEnumerable) to_add)
+			public IndexableGenerator (ICollection to_add) : this (to_add, null, null)
 			{
-				this.count = to_add.Count;
+			}
+
+			public IndexableGenerator (ICollection to_add, ICollection to_remove_uris) :
+				this (to_add, to_remove_uris, null)
+			{
+			}
+
+			public IndexableGenerator (ICollection to_add, ICollection to_remove_uris, LuceneQueryable submitter_queryable)
+			{
+				this.count = 0;
+				this.submitter_queryable = submitter_queryable;
+
+				if (to_add != null) {
+					this.to_add_enumerator = to_add.GetEnumerator ();
+					this.count += to_add.Count;
+				}
+
+				if (to_remove_uris != null) {
+					this.to_remove_uris_enumerator = to_remove_uris.GetEnumerator ();
+					this.count += to_remove_uris.Count;
+				}
+			}
+
+			public LuceneQueryable SubmitterQueryable {
+				set { submitter_queryable = value; }
 			}
 
 			public Indexable GetNextIndexable ()
 			{
+				if (to_remove_uris_enumerator != null) {
+					Uri uri_to_remove = to_remove_uris_enumerator.Current as Uri;
+					if (uri_to_remove == null)
+						return null;
+
+					return new Indexable (IndexableType.Remove, uri_to_remove);
+				}
+
+				if (to_add_enumerator == null)
+					return null;
+
 				return to_add_enumerator.Current as Indexable;
 			}
-			
+
 			public bool HasNextIndexable ()
 			{
 				++done_count;
+
+				if (to_remove_uris_enumerator != null) {
+					if (to_remove_uris_enumerator.MoveNext ())
+						return true;
+					else
+						to_remove_uris_enumerator = null;
+				}
+
+				if (to_add_enumerator == null)
+					return false;
+
 				return to_add_enumerator.MoveNext ();
 			}
 
@@ -295,17 +347,38 @@ namespace Beagle.Daemon.IndexingServiceQueryable {
 		{
 			IndexingServiceRequest isr = (IndexingServiceRequest) msg;
 
-			foreach (Uri uri in isr.ToRemove) {
-				Scheduler.Task task = NewRemoveTask (uri);
-				ThisScheduler.Add (task);
+			LuceneQueryable backend = this;
+
+			if (isr.Source != null) {
+				Queryable target = QueryDriver.GetQueryable (isr.Source);
+
+				if (target == null) {
+					string err = String.Format ("Unable to find backend matching '{0}'", isr.Source);
+
+					Log.Error (err);
+					return new ErrorResponse (err);
+				}
+
+				if (! (target.IQueryable is LuceneQueryable)) {
+					string err = String.Format ("Backend '{0}' is not an indexed backend", isr.Source);
+
+					Log.Error (err);
+					return new ErrorResponse (err);
+				}
+
+				backend = (LuceneQueryable) target.IQueryable;
+				Log.Debug ("Found backend for IndexingServiceRequest: {0}", backend.IndexName);
 			}
 
 			// FIXME: There should be a way for the request to control the
 			// scheduler priority of the task.
 
-			if (isr.ToAdd.Count > 0) {
-				IIndexableGenerator ind_gen = new IndexableGenerator (isr.ToAdd);
-				Scheduler.Task task = NewAddTask (ind_gen);
+			if (isr.ToAdd.Count > 0 || isr.ToRemove.Count > 0) {
+				Log.Debug ("IndexingService: Adding {0} indexables, removing {1} indexables.", isr.ToAdd.Count, isr.ToRemove.Count);
+
+				IndexableGenerator ind_gen;
+				ind_gen = new IndexableGenerator (isr.ToAdd, isr.ToRemove, this);
+				Scheduler.Task task = backend.NewAddTask (ind_gen);
 				task.Priority = Scheduler.Priority.Immediate;
 				ThisScheduler.Add (task);
 			}
