@@ -30,20 +30,23 @@ using System.IO;
 using System.Text;
 using System.Reflection;
 using System.Collections;
+using System.Collections.Generic;
 
 using Beagle;
 using Beagle.Daemon;
 using Beagle.Util;
 
-class InfoTool {
+// Assembly information
+[assembly: AssemblyTitle ("beagle-info")]
+[assembly: AssemblyDescription ("Statistics from the Beagle daemon")]
+
+public class InfoTool {
 
 	public static void PrintUsageAndExit () 
 	{
+		VersionFu.PrintHeader ();
+
 		string usage =
-			"beagle-info: Statistics from the Beagle daemon.\n" +
-			"Web page: http://www.gnome.org/projects/beagle\n" +
-			"Copyright (C) 2004-2006 Novell, Inc.\n\n";
-		usage +=
 			"Usage: beagle-info <OPTIONS>\n\n" +
 			"Options:\n" +
 			"  --daemon-version\t\tPrint the version of the running daemon.\n" +
@@ -54,7 +57,8 @@ class InfoTool {
 			"  --list-backends\t\tList the currently available backends.\n" +
 			"  --list-filters\t\tList the currently available filters.\n" +
 			"  --list-static-indexes\t\tList the available static indexes.\n" +
-			"  --help\t\t\tPrint this usage message.\n";
+			"  --help\t\t\tPrint this usage message.\n" +
+			"  --version\t\t\tPrint version information.\n";
 
 		Console.WriteLine (usage);
 
@@ -66,6 +70,11 @@ class InfoTool {
 		if (args.Length == 0 || Array.IndexOf (args, "--help") > -1)
 			PrintUsageAndExit ();
 
+		if (Array.IndexOf (args, "--version") > -1) {
+			VersionFu.PrintVersion ();
+			return 0;
+		}
+
 		if (Array.IndexOf (args, "--list-filters") > -1)
 			PrintFilterInformation ();
 		else if (Array.IndexOf (args, "--list-backends") > -1)
@@ -152,14 +161,10 @@ class InfoTool {
 			bool has_filter = false;
 
 			foreach (FilterFlavor flavor in filter.SupportedFlavors) {
-				if (flavor.MimeType != null && (! flavor.MimeType.StartsWith ("beagle"))) {
-					sb.Append ("  - " + flavor.MimeType + "\n");
-					has_filter = true;
-				}
-				if (flavor.Extension != null) {
-					sb.Append ("  - *" + flavor.Extension + "\n");
-					has_filter = true;
-				}
+				sb.Append ("  - ");
+				sb.Append (flavor);
+				sb.Append ("\n");
+				has_filter = true;
 			}
 
 			if (has_filter)
@@ -205,8 +210,16 @@ class InfoTool {
 				Console.WriteLine ("[System index] " + index_dir.Name + " (" + index_dir.FullName + ")");
 		} catch (DirectoryNotFoundException) { }
 
-		foreach (string index_path in Conf.Daemon.StaticQueryables)
-			Console.WriteLine ("[User index]   " + index_path);
+		Config config = Conf.Load (Conf.Names.DaemonConfig);
+		if (config == null)
+			return;
+
+		List<string[]> values = config.GetListOptionValues (Conf.Names.StaticQueryables);
+		if (values == null)
+			return;
+
+		foreach (string[] index_path in values)
+			Console.WriteLine ("[User index]   " + index_path [0]);
 	}
 	
 }
