@@ -40,7 +40,11 @@ using Beagle;
 using Beagle.Util;
 using Beagle.Daemon;
 
-class QueryTool {
+// Assembly information
+[assembly: AssemblyTitle ("beagle-query")]
+[assembly: AssemblyDescription ("Command-line interface to the Beagle search system")]
+
+public class QueryTool {
 
 	private static int count = 0;
 	private static Query query = null;
@@ -48,14 +52,14 @@ class QueryTool {
 	private static DateTime lastQueryTime = DateTime.Now;
 
 	private static MainLoop main_loop = null;
+
 	// CLI args
 	private static bool keep_running = false;
 	private static bool verbose = false;
 	private static bool display_hits = true;
 	private static bool flood = false;
 	private static bool listener = false;
-	private static DateTime start_date = DateTime.MinValue;
-	private static DateTime end_date = DateTime.MinValue;
+	private static bool display_cached_text = false;
 
 	private static void OnHitsAdded (HitsAddedResponse response)
 	{
@@ -82,9 +86,13 @@ class QueryTool {
 
 			if (verbose) {
 				SnippetRequest sreq = new SnippetRequest (query, hit);
+				if (display_cached_text)
+					sreq.FullText = true;
+
 				SnippetResponse sresp = (SnippetResponse) sreq.Send ();
 				Console.WriteLine ("PaUri: {0}", hit.ParentUri != null ? hit.ParentUri.ToString () : "(null)");
-				Console.WriteLine (" Snip: {0}", sresp.Snippet != null ? sresp.Snippet : "(null)");
+				if (! display_cached_text)
+					Console.WriteLine (" Snip: {0}", sresp.Snippet != null ? sresp.Snippet : "(null)");
 				Console.WriteLine (" Type: {0}", hit.Type);
 				Console.WriteLine ("MimeT: {0}", hit.MimeType == null ? "(null)" : hit.MimeType);
 				Console.WriteLine ("  Src: {0}", hit.Source);
@@ -93,8 +101,25 @@ class QueryTool {
 					Console.WriteLine (" Time: {0}", DateTimeUtil.ToString (hit.Timestamp));
 				
 				foreach (Property prop in hit.Properties)
-					Console.WriteLine ("    {0} = '{1}'", prop.Key, prop.Value);
+					Console.WriteLine ("    {0} = '{1}'",
+						prop.Key,
+						(prop.Type != PropertyType.Date ? prop.Value : DateTimeUtil.ToString (StringFu.StringToDateTime (prop.Value))));
 				
+
+				if (display_cached_text) {
+					Console.WriteLine ("-- Cache -------------------------------------");
+					if (sresp.SnippetList.Snippets == null)
+						Console.WriteLine ("(empty)");
+					else {
+						foreach (SnippetLine snippet_line in sresp.SnippetList.Snippets) {
+							if (snippet_line == null || snippet_line.Fragments == null)
+								Console.WriteLine ("(empty)");
+							else
+								Console.WriteLine (((Fragment)snippet_line.Fragments [0]).Text);
+						}
+					}
+					Console.WriteLine ("----------------------------------------------");
+				}
 				Console.WriteLine ();
 			}
 
@@ -133,35 +158,32 @@ class QueryTool {
 
 	public static void PrintUsageAndExit () 
 	{
+		VersionFu.PrintHeader ();
+
 		string usage =
-			"beagle-query: Command-line interface to the Beagle search system.\n" +
-			"Web page: http://www.gnome.org/projects/beagle\n" +
-			"Copyright (C) 2004-2006 Novell, Inc.\n\n";
-		usage +=
 			"Usage: beagle-query [OPTIONS] <query string>\n\n" +
 			"Options:\n" +
-			"  --verbose\t\t\tPrint detailed information about each hit.\n" +
-			"  --mime <mime type>\t\tConstrain search results to the specified mime\n" +
-			"                    \t\ttype. Can be used multiply.\n" +
-			"  --type <hit type>\t\tConstrain search results to the specified hit\n" +
-			"                    \t\ttype. Can be used multiply.\n" +
-			"  --source <source>\t\tConstrain query to the specified source.\n" +
-			"                   \t\tSources list available from beagle-status.\n" +
-			"  --start <date>\t\tConstrain query to items after specified date.\n" +
-			"                \t\tDate must be in the form \"yyyyMMdd\" or \"yyyyMMddHHmmss\"\n" +
-			"  --end <date>\t\t\tConstrain query to items before specified date.\n" +
-			"              \t\t\tDate must be in the form \"yyyyMMdd\" or \"yyyyMMddHHmmss\"\n" +
-			"  --keywords\t\t\tLists the keywords allowed in 'query string'.\n" +
-			"            \t\t\tKeyword queries can be specified as keywordname:value e.g. ext:jpg\n" +
-			"  --live-query\t\t\tRun continuously, printing notifications if a\n" +
-			"              \t\t\tquery changes.\n" +
-			"  --stats-only\t\t\tOnly display statistics about the query, not\n" +
-			"              \t\t\tthe actual results.\n" +
-			"  --max-hits\t\t\tLimit number of search results per backend\n" +
-			"            \t\t\t(default = 100, max = 100)\n" +
-			"  --flood\t\t\tExecute the query over and over again.  Don't do that.\n" +
-			"  --listener\t\t\tExecute an index listener query.  Don't do that either.\n" +
-			"  --help\t\t\tPrint this usage message.\n" +
+			"  --verbose\t\tPrint detailed information about each hit.\n" +
+			"  --cache\t\tShow the entire cached text instead of a snippet\n" +
+			"         \t\tshowing the matches, requires --verbose.\n" +
+			"         \t\tFor large documents this will produce extremely large output,\n" +
+			"         \t\tso use this with uri queries or queries returning only a few results\n" + 
+			"         \t\tNot recommended for live-queries or stats-only queries.\n" +
+			"  --keywords\t\tLists the keywords allowed in 'query string'.\n" +
+			"            \t\tKeyword queries can be specified as keywordname:value e.g. ext:jpg\n" +
+			"  --live-query\t\tRun continuously, printing notifications if a\n" +
+			"              \t\tquery changes.\n" +
+			"  --stats-only\t\tOnly display statistics about the query, not\n" +
+			"              \t\tthe actual results.\n" +
+			"  --max-hits\t\tLimit number of search results per backend\n" +
+			"            \t\t(default 100)\n" +
+			"\n" +
+			"  --network <yes|no>\tQuery other beagle systems in the network specified in config (default no)\n" +
+			"\n" +
+			"  --flood\t\tExecute the query over and over again.  Don't do that.\n" +
+			"  --listener\t\tExecute an index listener query.  Don't do that either.\n" +
+			"  --help\t\tPrint this usage message.\n" +
+			"  --version\t\tPrint version information.\n" +
 			"\n" +
 			"Query string supports an advanced query syntax.\n" +
 			"For details of the query syntax, please see http://beagle-project.org/Searching_Data\n" +
@@ -253,12 +275,12 @@ class QueryTool {
 		if (args.Length == 0 || Array.IndexOf (args, "--help") > -1 || Array.IndexOf (args, "--usage") > -1)
 			PrintUsageAndExit ();
 
-		StringBuilder query_str =  new StringBuilder ();
+		if (Array.IndexOf (args, "--version") > -1) {
+			VersionFu.PrintVersion ();
+			Environment.Exit (0);
+		}
 
-		string[] formats = {
-			"yyyyMMdd",
-			"yyyyMMddHHmmss"
-		};
+		StringBuilder query_str =  new StringBuilder ();
 
 		query = new Query ();
 
@@ -267,24 +289,15 @@ class QueryTool {
 		while (i < args.Length) {
 			switch (args [i]) {
 
-			case "--mime":
-			        if (++i >= args.Length) PrintUsageAndExit ();
-				query.AddMimeType (args [i]);
-				break;
-			case "--type":
-			        if (++i >= args.Length) PrintUsageAndExit ();
-				query.AddHitType (args [i]);
-				break;
-			case "--source":
-			        if (++i >= args.Length) PrintUsageAndExit ();
-				query.AddSource (args [i]);
-				break;
 			case "--live-query":
 				keep_running = true;
 				break;
 			case "--verbose":
 				verbose = true;
 				break;
+			case "--cache":
+				display_cached_text = true;
+				break;
 			case "--stats-only":
 				verbose = true;
 				display_hits = false;
@@ -300,88 +313,53 @@ class QueryTool {
 				listener = true;
 				keep_running = true;
 				break;
-			case "--start":
-				if (++i >= args.Length) PrintUsageAndExit ();
-				try {
-					start_date = DateTime.ParseExact (args[i], formats,
-									  CultureInfo.InvariantCulture,
-									  DateTimeStyles.None);
-				} catch (FormatException) {
-					Console.WriteLine ("Invalid start date");
-					System.Environment.Exit (-1);
-				}
-				start_date = start_date.ToUniversalTime ();
-				break;
-
-			case "--end":
-				if (++i >= args.Length) PrintUsageAndExit ();
-				try {
-					end_date = DateTime.ParseExact (args[i], formats,
-									CultureInfo.InvariantCulture,
-									DateTimeStyles.None);
-				} catch (FormatException) {
-					Console.WriteLine ("Invalid end date");
-					System.Environment.Exit (-1);
-				}
-				end_date = end_date.ToUniversalTime ();
-				break;
-
 			case "--keywords":
 				ReadBackendMappings ();
 				QueryDriver.ReadKeywordMappings ();
 
 				Console.WriteLine ("Supported query keywords are:");
 
-				IDictionaryEnumerator property_keyword_enum = PropertyKeywordFu.MappingEnumerator;
-				while (property_keyword_enum.MoveNext ()) {
-					PropertyDetail prop = property_keyword_enum.Value as PropertyDetail;
-					if (prop.Description != null)
-						Console.WriteLine ("  {0,-20} for {1}", property_keyword_enum.Key, prop.Description);
-					else
-						Console.WriteLine ("  {0,-20}", property_keyword_enum.Key);
+				foreach (string key in PropertyKeywordFu.Keys) {
+					foreach (PropertyDetail prop in PropertyKeywordFu.Properties (key)) {
+						// Dont print properties without description; they confuse people
+						if (string.IsNullOrEmpty (prop.Description))
+							continue;
+						Console.WriteLine ("  {0,-20} for {1}", key, prop.Description);
+					}
 				}
 
 				System.Environment.Exit (0);
 				break;
 
+			case "--network":
+				if (++i >= args.Length) PrintUsageAndExit ();
+				if (args [i].ToLower () == "yes")
+					query.AddDomain (QueryDomain.Neighborhood);
+				break;
+
 			default:
+				if (args [i].StartsWith ("--"))
+					PrintUsageAndExit ();
 				if (query_str.Length > 0)
 					query_str.Append (' ');
 				query_str.Append (args [i]);
 				
 				break;
-				
 			}
 
 			++i;
 		}
 
 		if (listener) {
-
 			query.IsIndexListener = true;
-
 		} else {
-		
 			if (query_str.Length > 0)
 				query.AddText (query_str.ToString ());
-
-			if (start_date != DateTime.MinValue || end_date != DateTime.MinValue) {
-				QueryPart_DateRange part = new QueryPart_DateRange ();
-				
-				if (start_date != DateTime.MinValue)
-					part.StartDate = start_date;
-
-				if (end_date != DateTime.MinValue)
-					part.EndDate = end_date;
-				
-				query.AddPart (part);
-			}
 		}
 
 		query.HitsAddedEvent += OnHitsAdded;
 		query.HitsSubtractedEvent += OnHitsSubtracted;
 
-
 		if (! keep_running)
 			query.FinishedEvent += OnFinished;
 		else
@@ -391,7 +369,5 @@ class QueryTool {
 
 		main_loop.Run ();
 	}
-
-
 }
 	
